@@ -60,7 +60,8 @@ sub ladspa_plugin_list {
 	my %seen;
 	for my $dir ( split ':', ladspa_path()){
 		next unless -d $dir;
-		opendir my ($dirh), $dir;
+		opendir(my $dirh, $dir)
+			or die "can't open directory $dir for read: $!";
 		push @plugins,  
 			map{"$dir/$_"} 						# full path
 			grep{ ! $seen{$_} and ++$seen{$_}}  # skip seen plugins
@@ -74,7 +75,8 @@ sub lv2_plugin_list {
 	my %seen;
 	for my $dir ( split ':', lv2_path()){
 		next unless -d $dir;
-		opendir my ($dirh), $dir;
+		opendir(my $dirh, $dir)
+			or die "can't open directory $dir for read: $!";
 		push @plugins,  
 			map{"$dir/$_"} 						# full path
 			grep{ ! $seen{$_} and ++$seen{$_}}  # skip seen plugins
@@ -120,7 +122,7 @@ sub prepare_effect_index {
 		}
 		$fx_cache->{partial_label_to_full}->{$code} = $code;
 	} grep{ !/^elv2:/ }keys %{$fx_cache->{full_label_to_index}};
-	#print yaml_out $fx_cache->{partial_label_to_full};
+	#print json_out $fx_cache->{partial_label_to_full};
 }
 sub extract_effects_data {
 	logsub("&extract_effects_data");
@@ -170,7 +172,7 @@ sub extract_effects_data {
 }
 sub sort_ladspa_effects {
 	logsub("&sort_ladspa_effects");
-#	print yaml_out($fx_cache->{split}); 
+#	print json_out($fx_cache->{split}); 
 	my $aa = $fx_cache->{split}->{ladspa}{a};
 	my $zz = $fx_cache->{split}->{ladspa}{z};
 #	print "start: $aa end $zz\n";
@@ -212,12 +214,12 @@ sub read_in_effects_data {
 	# split on newlines
 	my @lv2 = split /\n/,$lv2;
 
-	logpkg(__FILE__,__LINE__,'trace',sub{ yaml_out(\@lv2) });
+	logpkg(__FILE__,__LINE__,'trace',sub{ json_out(\@lv2) });
 
 	# join pairs of lines
 	@lv2 = map { join " ", splice(@lv2,0,2) } 1..@lv2/2;
 
-	logpkg(__FILE__,__LINE__,'trace',sub{ yaml_out(\@lv2) });
+	logpkg(__FILE__,__LINE__,'trace',sub{ json_out(\@lv2) });
 
 	my @preset = grep {! /^\w*$/ } split "\n", eval_iam("preset-register");
 	my @ctrl  = grep {! /^\w*$/ } split "\n", eval_iam("ctrl-register");
@@ -347,7 +349,7 @@ sub read_in_effects_data {
 		 logpkg(__FILE__,__LINE__,'debug', "i: $i code: $fx_cache->{registry}->[$i]->{code} display: $fx_cache->{registry}->[$i]->{display}");
 	}
 
-	logpkg(__FILE__,__LINE__,'debug', sub{"$fx_cache->{registry}\n======\n", yaml_out($fx_cache->{registry})}); ; 
+	logpkg(__FILE__,__LINE__,'debug', sub{"$fx_cache->{registry}\n======\n", json_out($fx_cache->{registry})}); ; 
 }
 
 sub integrate_cop_hints {
@@ -448,7 +450,7 @@ sub get_ladspa_hints{
 		#last if ++$i > 10;
 	}
 
-	logpkg(__FILE__,__LINE__,'debug', sub{yaml_out($fx_cache->{ladspa})});
+	logpkg(__FILE__,__LINE__,'debug', sub{json_out($fx_cache->{ladspa})});
 }
 
 sub get_lv2_hints {
@@ -530,7 +532,7 @@ logpkg(__FILE__,__LINE__,'debug', sub {join "\n", sort keys %{$fx_cache->{ladspa
 logpkg(__FILE__,__LINE__,'debug', '-' x 60);
 logpkg(__FILE__,__LINE__,'debug', sub{join "\n", grep {/el:/} sort keys %{$fx_cache->{full_label_to_index}}});
 
-#print yaml_out $fx_cache->{registry}; exit;
+#print json_out $fx_cache->{registry}; exit;
 
 }
 
